@@ -37,7 +37,7 @@ class POT(Command):  # {{{
         kw['cwd'] = kw.get('cwd', self.TRANSLATIONS)
         if hasattr(cmd, 'format'):
             cmd = shlex.split(cmd)
-        cmd = ['tx', '--traceback'] + cmd
+        cmd = [os.environ.get('TX', 'tx')] + cmd
         self.info(' '.join(cmd))
         return subprocess.check_call(cmd, **kw)
 
@@ -690,7 +690,7 @@ class GetTranslations(Translations):  # {{{
         if opts.check_for_errors:
             self.check_all()
             return
-        self.tx('pull -a --parallel --no-interactive')
+        self.tx('pull -a')
         if not self.is_modified:
             self.info('No translations were updated')
             return
