@@ -23,7 +23,7 @@ from calibre import (
     fit_image, force_unicode, human_readable, isbytestring, prepare_string_for_xml,
     strftime
 )
-from calibre.constants import DEBUG, config_dir, filesystem_encoding
+from calibre.constants import DEBUG, config_dir, dark_link_color, filesystem_encoding
 from calibre.db.search import CONTAINS_MATCH, EQUALS_MATCH, REGEXP_MATCH, _match
 from calibre.ebooks.metadata import authors_to_string, fmt_sidx, string_to_authors
 from calibre.ebooks.metadata.book.formatter import SafeFormat
@@ -52,6 +52,17 @@ ALIGNMENT_MAP = {'left': Qt.AlignmentFlag.AlignLeft, 'right': Qt.AlignmentFlag.A
 _default_image = None
 
 
+def render_pin(color='green', save_to=None):
+    svg = P('pin-template.svg', data=True).replace(b'fill:#f39509', ('fill:' + color).encode('utf-8'))
+    pm = QPixmap()
+    dpr = QApplication.instance().devicePixelRatio()
+    pm.setDevicePixelRatio(dpr)
+    pm.loadFromData(svg, 'svg')
+    if save_to:
+        pm.save(save_to)
+    return pm
+
+
 def default_image():
     global _default_image
     if _default_image is None:
@@ -240,8 +251,33 @@ class BooksModel(QAbstractTableModel):  # {{{
         self.current_highlighted_idx = None
         self.highlight_only = False
         self.row_height = 0
+        self.marked_text_icons = {}
         self.read_config()
 
+    def marked_text_icon_for(self, label):
+        import random
+        ans = self.marked_text_icons.get(label)
+        if ans is not None:
+            return ans[1]
+        used_labels = self.db.data.all_marked_labels()
+        for qlabel in tuple(self.marked_text_icons):
+            if qlabel not in used_labels:
+                del self.marked_text_icons[qlabel]
+        used_colors = {x[0] for x in self.marked_text_icons.values()}
+        if QApplication.instance().is_dark_theme:
+            all_colors = {dark_link_color, 'lightgreen', 'red', 'maroon', 'cyan', 'pink'}
+        else:
+            all_colors = {'blue', 'green', 'red', 'maroon', 'cyan', 'pink'}
+        for c in all_colors - used_colors:
+            color = c
+            break
+        else:
+            color = random.choice(sorted(all_colors))
+        pm = render_pin(color)
+        ans = QIcon(pm)
+        self.marked_text_icons[label] = color, ans
+        return ans
+
     def _clear_caches(self):
         self.color_cache = defaultdict(dict)
         self.icon_cache = defaultdict(dict)
@@ -764,6 +800,7 @@ class BooksModel(QAbstractTableModel):  # {{{
 
     def build_data_convertors(self):
         rating_fields = {}
+        bool_fields = set()
 
         def renderer(field, decorator=False):
             idfunc = self.db.id
@@ -775,6 +812,7 @@ class BooksModel(QAbstractTableModel):  # {{{
             dt = m['datatype']
 
             if decorator == 'bool':
+                bool_fields.add(field)
                 bt = self.db.new_api.pref('bools_are_tristate')
                 bn = self.bool_no_icon
                 by = self.bool_yes_icon
@@ -895,14 +933,23 @@ class BooksModel(QAbstractTableModel):  # {{{
 
         def stars_tooltip(func, allow_half=True):
             def f(idx):
-                ans = val = int(func(idx))
+                val = int(func(idx))
                 ans = str(val // 2)
                 if allow_half and val % 2:
                     ans += '.5'
                 return _('%s stars') % ans
             return f
+
+        def bool_tooltip(key):
+            def f(idx):
+                return self.db.new_api.fast_field_for(self.db.new_api.fields[key],
+                                                     self.db.id(idx))
+            return f
+
         for f, allow_half in iteritems(rating_fields):
             tc[f] = stars_tooltip(self.dc[f], allow_half)
+        for f in bool_fields:
+            tc[f] = bool_tooltip(f)
         # build a index column to data converter map, to remove the string lookup in the data loop
         self.column_to_dc_map = [self.dc[col] for col in self.column_map]
         self.column_to_tc_map = [tc[col] for col in self.column_map]
@@ -1061,7 +1108,12 @@ class BooksModel(QAbstractTableModel):  # {{{
             return (section+1)
         if role == Qt.ItemDataRole.DecorationRole:
             try:
-                return self.marked_icon if self.db.data.get_marked(self.db.data.index_to_id(section)) else self.row_decoration
+                m = self.db.data.get_marked(self.db.data.index_to_id(section))
+                if m:
+                    i = self.marked_icon if m == 'true' else self.marked_text_icon_for(m)
+                else:
+                    i = self.row_decoration
+                return i
             except (ValueError, IndexError):
                 pass
         return None
